---
title: <span class="badge object-type-scalar"></span> RowsPerMinute
---
# <span class="badge object-type-scalar"></span> RowsPerMinute

Throughput: rows/min (rpm)

## Definition

```python
# Throughput: rows/min (rpm)
RowsPerMinute: typing.Literal["rowspm"] = "rowspm"
```
